Module actions_disable_workflow

Module actions_disable_workflow 

Disable a workflow

Disables a workflow and sets the state of the workflow to disabled_manually. You can replace workflow_id with the workflow file name. For example, you could use main.yaml.

You must authenticate using an access token with the repo scope to use this endpoint. GitHub Apps must have the actions:write permission to use this endpoint.

API method documentation

Functions

http_builder
hyper_request
reqwest_blocking_builder
reqwest_blocking_request
reqwest_builder
reqwest_request