Module actions_get_workflow

Module actions_get_workflow 

Get a workflow

Gets a specific workflow. You can replace workflow_id with the workflow file name. For example, you could use main.yaml. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the repo scope. GitHub Apps must have the actions:read permission to use this endpoint.

API method documentation

Functions

http_builder
hyper_request
reqwest_blocking_builder
reqwest_blocking_request
reqwest_builder
reqwest_request