Delete an app token

OAuth application owners can revoke a single token for an OAuth application. You must use Basic Authentication when accessing this endpoint, using the OAuth application’s client_id and client_secret as the username and password.

API method documentation

Modules

Types for body parameter in super::apps_delete_token

Structs

Functions