Module jinxapi_github::v1_1_4::request::checks_create::body::json
source · [−]Expand description
Types for fields in Json
Modules
Structs
Check runs can accept a variety of data in the output object, including a title and summary and can optionally provide descriptive details about the run. See the output object description.