pub struct Annotations<'a> {
    pub path: Cow<'a, str>,
    pub start_line: i64,
    pub end_line: i64,
    pub start_column: Option<i64>,
    pub end_column: Option<i64>,
    pub annotation_level: Cow<'a, str>,
    pub message: Cow<'a, str>,
    pub title: Option<Cow<'a, str>>,
    pub raw_details: Option<Cow<'a, str>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

path: Cow<'a, str>

The path of the file to add an annotation to. For example, assets/css/main.css.

start_line: i64

The start line of the annotation.

end_line: i64

The end line of the annotation.

start_column: Option<i64>

The start column of the annotation. Annotations only support start_column and end_column on the same line. Omit this parameter if start_line and end_line have different values.

end_column: Option<i64>

The end column of the annotation. Annotations only support start_column and end_column on the same line. Omit this parameter if start_line and end_line have different values.

annotation_level: Cow<'a, str>

The level of the annotation. Can be one of notice, warning, or failure.

message: Cow<'a, str>

A short description of the feedback for these lines of code. The maximum size is 64 KB.

title: Option<Cow<'a, str>>

The title that represents the annotation. The maximum size is 255 characters.

raw_details: Option<Cow<'a, str>>

Details about this annotation. The maximum size is 64 KB.

additionalProperties: HashMap<Cow<'a, str>, Value>