Struct jinxapi_github::v1_1_4::request::checks_update::body::json::output::Annotations
source · [−]pub struct Annotations<'a> {
pub path: Cow<'a, str>,
pub start_line: i64,
pub end_line: i64,
pub start_column: Option<i64>,
pub end_column: Option<i64>,
pub annotation_level: Cow<'a, str>,
pub message: Cow<'a, str>,
pub title: Option<Cow<'a, str>>,
pub raw_details: Option<Cow<'a, str>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
path: Cow<'a, str>The path of the file to add an annotation to. For example, assets/css/main.css.
start_line: i64The start line of the annotation.
end_line: i64The end line of the annotation.
start_column: Option<i64>The start column of the annotation. Annotations only support start_column and end_column on the same line. Omit this parameter if start_line and end_line have different values.
end_column: Option<i64>The end column of the annotation. Annotations only support start_column and end_column on the same line. Omit this parameter if start_line and end_line have different values.
annotation_level: Cow<'a, str>The level of the annotation. Can be one of notice, warning, or failure.
message: Cow<'a, str>A short description of the feedback for these lines of code. The maximum size is 64 KB.
title: Option<Cow<'a, str>>The title that represents the annotation. The maximum size is 255 characters.
raw_details: Option<Cow<'a, str>>Details about this annotation. The maximum size is 64 KB.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'a> Clone for Annotations<'a>
impl<'a> Clone for Annotations<'a>
sourcefn clone(&self) -> Annotations<'a>
fn clone(&self) -> Annotations<'a>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'a> Debug for Annotations<'a>
impl<'a> Debug for Annotations<'a>
sourceimpl<'a> Default for Annotations<'a>
impl<'a> Default for Annotations<'a>
sourcefn default() -> Annotations<'a>
fn default() -> Annotations<'a>
Returns the “default value” for a type. Read more
sourceimpl<'de, 'a> Deserialize<'de> for Annotations<'a>
impl<'de, 'a> Deserialize<'de> for Annotations<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<'a> PartialEq<Annotations<'a>> for Annotations<'a>
impl<'a> PartialEq<Annotations<'a>> for Annotations<'a>
sourcefn eq(&self, other: &Annotations<'a>) -> bool
fn eq(&self, other: &Annotations<'a>) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &Annotations<'a>) -> bool
fn ne(&self, other: &Annotations<'a>) -> bool
This method tests for !=.
sourceimpl<'a> Serialize for Annotations<'a>
impl<'a> Serialize for Annotations<'a>
impl<'a> Eq for Annotations<'a>
impl<'a> StructuralEq for Annotations<'a>
impl<'a> StructuralPartialEq for Annotations<'a>