Output

Struct Output 

pub struct Output<'a> {
    pub title: Option<Cow<'a, str>>,
    pub summary: Cow<'a, str>,
    pub text: Option<Cow<'a, str>>,
    pub annotations: Option<Cow<'a, [Annotations<'a>]>>,
    pub images: Option<Cow<'a, [Images<'a>]>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}
Check runs can accept a variety of data in the output object, including a title and summary and can optionally provide descriptive details about the run. See the output object description.

Fields

title: Option<Cow<'a, str>>

Required.

summary: Cow<'a, str>

Can contain Markdown.

text: Option<Cow<'a, str>>

Can contain Markdown.

annotations: Option<Cow<'a, [Annotations<'a>]>>

Adds information from your analysis to specific lines of code. Annotations are visible in GitHub’s pull request UI. Annotations are visible in GitHub’s pull request UI. The Checks API limits the number of annotations to a maximum of 50 per API request. To create more than 50 annotations, you have to make multiple requests to the Update a check run endpoint. Each time you update the check run, annotations are appended to the list of annotations that already exist for the check run. For details about annotations in the UI, see “About status checks”. See the annotations object description for details.

images: Option<Cow<'a, [Images<'a>]>>

Adds images to the output displayed in the GitHub pull request UI. See the images object description for details.

additionalProperties: HashMap<Cow<'a, str>, Value>