pub struct Json<'a> {
    pub name: Option<Cow<'a, str>>,
    pub details_url: Option<Cow<'a, str>>,
    pub external_id: Option<Cow<'a, str>>,
    pub started_at: Option<Cow<'a, str>>,
    pub status: Option<Cow<'a, str>>,
    pub conclusion: Option<Cow<'a, str>>,
    pub completed_at: Option<Cow<'a, str>>,
    pub output: Option<Output<'a>>,
    pub actions: Option<Cow<'a, [Actions<'a>]>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

name: Option<Cow<'a, str>>

The name of the check. For example, “code-coverage”.

details_url: Option<Cow<'a, str>>

The URL of the integrator’s site that has the full details of the check.

external_id: Option<Cow<'a, str>>

A reference for the run on the integrator’s system.

started_at: Option<Cow<'a, str>>

This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.

status: Option<Cow<'a, str>>

The current status. Can be one of queued, in_progress, or completed.

conclusion: Option<Cow<'a, str>>

Required if you provide completed_at or a status of completed. The final conclusion of the check. Can be one of action_required, cancelled, failure, neutral, success, skipped, stale, or timed_out.
Note: Providing conclusion will automatically set the status parameter to completed. You cannot change a check run conclusion to stale, only GitHub can set this.

completed_at: Option<Cow<'a, str>>

The time the check completed. This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.

output: Option<Output<'a>>actions: Option<Cow<'a, [Actions<'a>]>>

Possible further actions the integrator can perform, which a user may trigger. Each action includes a label, identifier and description. A maximum of three actions are accepted. See the actions object description. To learn more about check runs and requested actions, see “Check runs and requested actions.”

additionalProperties: HashMap<Cow<'a, str>, Value>