Module code_scanning_get_sarif

Module code_scanning_get_sarif 

Get information about a SARIF upload

Gets information about a SARIF upload, including the status and the URL of the analysis that was uploaded so that you can retrieve details of the analysis. For more information, see “Get a code scanning analysis for a repository.” You must use an access token with the security_events scope to use this endpoint with private repos, the public_repo scope also grants permission to read security events on public repos only. GitHub Apps must have the security_events read permission to use this endpoint.

API method documentation

Functions

http_builder
hyper_request
reqwest_blocking_builder
reqwest_blocking_request
reqwest_builder
reqwest_request