Module jinxapi_github::v1_1_4::request::dependabot_get_org_secret
source · [−]Expand description
Get an organization secret
Gets a single organization secret without revealing its encrypted value. You must authenticate using an access token with the admin:org scope to use this endpoint. GitHub Apps must have the dependabot_secrets organization permission to use this endpoint.