Module jinxapi_github::v1_1_4::request::git_create_commit::body::json
source · [−]Expand description
Types for fields in Json
Structs
Information about the author of the commit. By default, the author will be the authenticated user and the current date. See the author and committer object below for details.
Information about the person who is making the commit. By default, committer will use the information set in author. See the author and committer object below for details.