Struct jinxapi_github::v1_1_4::request::git_create_commit::body::json::Committer
source · [−]pub struct Committer<'a> {
pub name: Option<Cow<'a, str>>,
pub email: Option<Cow<'a, str>>,
pub date: Option<Cow<'a, str>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Expand description
Information about the person who is making the commit. By default, committer will use the information set in author. See the author and committer object below for details.
Fields
name: Option<Cow<'a, str>>The name of the author (or committer) of the commit
email: Option<Cow<'a, str>>The email of the author (or committer) of the commit
date: Option<Cow<'a, str>>Indicates when this commit was authored (or committed). This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'de, 'a> Deserialize<'de> for Committer<'a>
impl<'de, 'a> Deserialize<'de> for Committer<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Committer<'a>
impl<'a> StructuralEq for Committer<'a>
impl<'a> StructuralPartialEq for Committer<'a>