pub struct Json<'a> {
    pub sha: Cow<'a, str>,
    pub force: Option<bool>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

sha: Cow<'a, str>

The SHA1 value to set this reference to

force: Option<bool>

Indicates whether to force the update or to make sure the update is a fast-forward update. Leaving this out or setting it to false will make sure you’re not overwriting work.

additionalProperties: HashMap<Cow<'a, str>, Value>