Module jinxapi_github::v1_1_4::request::gitignore_get_template
source · [−]Expand description
Get a gitignore template
The API also allows fetching the source of a single template. Use the raw media type to get the raw contents.