pub struct Json<'a> {
pub title: Value,
pub body: Option<Cow<'a, str>>,
pub assignee: Option<Option<Cow<'a, str>>>,
pub milestone: Option<Option<Value>>,
pub labels: Option<Cow<'a, [Value]>>,
pub assignees: Option<Cow<'a, [Cow<'a, str>]>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
title: ValueThe title of the issue.
body: Option<Cow<'a, str>>The contents of the issue.
assignee: Option<Option<Cow<'a, str>>>Login for the user that this issue should be assigned to. NOTE: Only users with push access can set the assignee for new issues. The assignee is silently dropped otherwise. This field is deprecated.
milestone: Option<Option<Value>>labels: Option<Cow<'a, [Value]>>Labels to associate with this issue. NOTE: Only users with push access can set labels for new issues. Labels are silently dropped otherwise.
assignees: Option<Cow<'a, [Cow<'a, str>]>>Logins for Users to assign to this issue. NOTE: Only users with push access can set assignees for new issues. Assignees are silently dropped otherwise.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
Sourceimpl<'de, 'a> Deserialize<'de> for Json<'a>
impl<'de, 'a> Deserialize<'de> for Json<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Json<'a>
impl<'a> StructuralPartialEq for Json<'a>