Lock an issue

Users with push access can lock an issue or pull request’s conversation.

Note that, if you choose not to pass any parameters, you’ll need to set Content-Length to zero when calling out to this endpoint. For more information, see “HTTP verbs.”

API method documentation

Modules

Types for body parameter in super::issues_lock

Structs

Functions