Module jinxapi_github::v1_1_4::request::issues_remove_label
source · [−]Expand description
Remove a label from an issue
Removes the specified label from the issue, and returns the remaining labels on the issue. This endpoint returns a 404 Not Found status if the label does not exist.