Module jinxapi_github::v1_1_4::request::issues_set_labels
source · [−]Expand description
Set labels for an issue
Removes any previous labels and sets the new labels for an issue.
Set labels for an issue
Removes any previous labels and sets the new labels for an issue.