Module jinxapi_github::v1_1_4::request::meta_get_zen
source · [−]Expand description
Get the Zen of GitHub
Get a random sentence from the Zen of GitHub
Get the Zen of GitHub
Get a random sentence from the Zen of GitHub