Update Git LFS preference

You can import repositories from Subversion, Mercurial, and TFS that include files larger than 100MB. This ability is powered by Git LFS. You can learn more about our LFS feature and working with large files on our help site.

API method documentation

Modules

Types for body parameter in super::migrations_set_lfs_preference

Structs

Functions