Create an organization webhook
Here’s how you can create a hook that posts payloads in JSON format:
Modules
- body
- Types for body parameter in
super::orgs_create_webhook
Create an organization webhook
Here’s how you can create a hook that posts payloads in JSON format:
super::orgs_create_webhook