Get the audit log for an organization

Gets the audit log for an organization. For more information, see “Reviewing the audit log for your organization.”

To use this endpoint, you must be an organization owner, and you must use an access token with the admin:org scope. GitHub Apps must have the organization_administration read permission to use this endpoint.

API method documentation

Functions