Module jinxapi_github::v1_1_4::request::orgs_ping_webhook
source · [−]Expand description
Ping an organization webhook
This will trigger a ping event to be sent to the hook.
Ping an organization webhook
This will trigger a ping event to be sent to the hook.