Module jinxapi_github::v1_1_4::request::orgs_update_webhook
source · [−]Expand description
Update an organization webhook
Updates a webhook configured in an organization. When you update a webhook, the secret will be overwritten. If you previously had a secret set, you must provide the same secret or set a new secret or the secret will be removed. If you are only updating individual webhook config properties, use “Update a webhook configuration for an organization.”
Modules
Types for body parameter in super::orgs_update_webhook