Module jinxapi_github::v1_1_4::request::projects_add_collaborator
source · [−]Expand description
Add project collaborator
Adds a collaborator to an organization project and sets their permission level. You must be an organization owner or a project admin to add a collaborator.
Modules
Types for body parameter in super::projects_add_collaborator