Create a repository project

Creates a repository project board. Returns a 404 Not Found status if projects are disabled in the repository. If you do not have sufficient privileges to perform this action, a 401 Unauthorized or 410 Gone status is returned.

API method documentation

Modules

Types for body parameter in super::projects_create_for_repo

Structs

Functions