Struct jinxapi_github::v1_1_4::request::pulls_create::body::Json
source · [−]pub struct Json<'a> {
pub title: Option<Cow<'a, str>>,
pub head: Cow<'a, str>,
pub base: Cow<'a, str>,
pub body: Option<Cow<'a, str>>,
pub maintainer_can_modify: Option<bool>,
pub draft: Option<bool>,
pub issue: Option<i64>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
title: Option<Cow<'a, str>>The title of the new pull request.
head: Cow<'a, str>The name of the branch where your changes are implemented. For cross-repository pull requests in the same network, namespace head with a user like this: username:branch.
base: Cow<'a, str>The name of the branch you want the changes pulled into. This should be an existing branch on the current repository. You cannot submit a pull request to one repository that requests a merge to a base of another repository.
body: Option<Cow<'a, str>>The contents of the pull request.
maintainer_can_modify: Option<bool>Indicates whether maintainers can modify the pull request.
draft: Option<bool>Indicates whether the pull request is a draft. See “Draft Pull Requests” in the GitHub Help documentation to learn more.
issue: Option<i64>additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'de, 'a> Deserialize<'de> for Json<'a>
impl<'de, 'a> Deserialize<'de> for Json<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Json<'a>
impl<'a> StructuralEq for Json<'a>
impl<'a> StructuralPartialEq for Json<'a>