Module jinxapi_github::v1_1_4::request::reactions_delete_legacy
source · [−]Expand description
Delete a reaction (Legacy)
Deprecation Notice: This endpoint route is deprecated and will be removed from the Reactions API. We recommend migrating your existing code to use the new delete reactions endpoints. For more information, see this blog post.
OAuth access tokens require the write:discussion scope, when deleting a team discussion or team discussion comment.