Module jinxapi_github::v1_1_4::request::repos_create_release
source · [−]Expand description
Create a release
Users with push access to the repository can create a release.
This endpoint triggers notifications. Creating content too quickly using this endpoint may result in secondary rate limiting. See “Secondary rate limits” and “Dealing with secondary rate limits” for details.
Modules
Types for body parameter in super::repos_create_release