Create a repository webhook

Repositories can have multiple webhooks installed. Each webhook should have a unique config. Multiple webhooks can share the same config as long as those webhooks do not have any events that overlap.

API method documentation

Modules

Types for body parameter in super::repos_create_webhook

Structs

Functions