Module jinxapi_github::v1_1_4::request::repos_delete_file
source · [−]Expand description
Delete a file
Deletes a file in a repository.
You can provide an additional committer parameter, which is an object containing information about the committer. Or, you can provide an author parameter, which is an object containing information about the author.
The author section is optional and is filled in with the committer information if omitted. If the committer information is omitted, the authenticated user’s information is used.
You must provide values for both name and email, whether you choose to use author or committer. Otherwise, you’ll receive a 422 status code.
Modules
Types for body parameter in super::repos_delete_file