Module jinxapi_github::v1_1_4::request::repos_delete_release
source · [−]Expand description
Delete a release
Users with push access to the repository can delete a release.
Delete a release
Users with push access to the repository can delete a release.