Disable vulnerability alerts

Disables dependency alerts and the dependency graph for a repository. The authenticated user must have admin access to the repository. For more information, see “About security alerts for vulnerable dependencies”.

API method documentation

Functions