Module jinxapi_github::v1_1_4::request::repos_get_all_environments
source · [−]Expand description
Get all environments
Get all environments for a repository.
Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the repo scope. GitHub Apps must have the actions:read permission to use this endpoint.