Module jinxapi_github::v1_1_4::request::repos_get_deployment_status
source · [−]Expand description
Get a deployment status
Users with pull access can view a deployment status for a deployment:
Get a deployment status
Users with pull access can view a deployment status for a deployment: