Module jinxapi_github::v1_1_4::request::repos_get_environment
source · [−]Expand description
Get an environment
Anyone with read access to the repository can use this endpoint. If the repository is private, you must use an access token with the repo scope. GitHub Apps must have the actions:read permission to use this endpoint.