Module jinxapi_github::v1_1_4::request::repos_list_invitations
source · [−]Expand description
List repository invitations
When authenticating as a user with admin rights to a repository, this endpoint will list all currently open repository invitations.