List repository languages

Lists languages for the specified repository. The value shown for each language is the number of bytes of code written in that language.

API method documentation

Functions