Module jinxapi_github::v1_1_4::request::repos_list_public
source · [−]Expand description
List public repositories
Lists all public repositories in the order that they were created.
Note:
- For GitHub Enterprise Server, this endpoint will only list repositories available to all users on the enterprise.
- Pagination is powered exclusively by the
sinceparameter. Use the Link header to get the URL for the next page of repositories.