Module jinxapi_github::v1_1_4::request::repos_test_push_webhook
source · [−]Expand description
Test the push repository webhook
This will trigger the hook with the latest push to the current repository if the hook is subscribed to push events. If the hook is not subscribed to push events, the server will respond with 204 but no test POST will be generated.
Note: Previously /repos/:owner/:repo/hooks/:hook_id/test