pub struct SecurityAndAnalysis<'a> {
    pub advanced_security: Option<AdvancedSecurity<'a>>,
    pub secret_scanning: Option<SecretScanning<'a>>,
    pub secret_scanning_push_protection: Option<SecretScanningPushProtection<'a>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}
Specify which security and analysis features to enable or disable. For example, to enable GitHub Advanced Security, use this data in the body of the PATCH request: {"security_and_analysis": {"advanced_security": {"status": "enabled"}}}. If you have admin permissions for a private repository covered by an Advanced Security license, you can check which security and analysis features are currently enabled by using a GET /repos/{owner}/{repo} request.

Fields

advanced_security: Option<AdvancedSecurity<'a>>secret_scanning: Option<SecretScanning<'a>>secret_scanning_push_protection: Option<SecretScanningPushProtection<'a>>additionalProperties: HashMap<Cow<'a, str>, Value>