pub struct Json<'a> {
Show 19 fields pub name: Option<Cow<'a, str>>, pub description: Option<Cow<'a, str>>, pub homepage: Option<Cow<'a, str>>, pub private: Option<bool>, pub visibility: Option<Cow<'a, str>>, pub security_and_analysis: Option<Option<SecurityAndAnalysis<'a>>>, pub has_issues: Option<bool>, pub has_projects: Option<bool>, pub has_wiki: Option<bool>, pub is_template: Option<bool>, pub default_branch: Option<Cow<'a, str>>, pub allow_squash_merge: Option<bool>, pub allow_merge_commit: Option<bool>, pub allow_rebase_merge: Option<bool>, pub allow_auto_merge: Option<bool>, pub delete_branch_on_merge: Option<bool>, pub archived: Option<bool>, pub allow_forking: Option<bool>, pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

name: Option<Cow<'a, str>>

The name of the repository.

description: Option<Cow<'a, str>>

A short description of the repository.

homepage: Option<Cow<'a, str>>

A URL with more information about the repository.

private: Option<bool>

Either true to make the repository private or false to make it public. Default: false.
Note: You will get a 422 error if the organization restricts changing repository visibility to organization owners and a non-owner tries to change the value of private. Note: You will get a 422 error if the organization restricts changing repository visibility to organization owners and a non-owner tries to change the value of private.

visibility: Option<Cow<'a, str>>

Can be public or private. If your organization is associated with an enterprise account using GitHub Enterprise Cloud or GitHub Enterprise Server 2.20+, visibility can also be internal.“

security_and_analysis: Option<Option<SecurityAndAnalysis<'a>>>has_issues: Option<bool>

Either true to enable issues for this repository or false to disable them.

has_projects: Option<bool>

Either true to enable projects for this repository or false to disable them. Note: If you’re creating a repository in an organization that has disabled repository projects, the default is false, and if you pass true, the API returns an error.

has_wiki: Option<bool>

Either true to enable the wiki for this repository or false to disable it.

is_template: Option<bool>

Either true to make this repo available as a template repository or false to prevent it.

default_branch: Option<Cow<'a, str>>

Updates the default branch for this repository.

allow_squash_merge: Option<bool>

Either true to allow squash-merging pull requests, or false to prevent squash-merging.

allow_merge_commit: Option<bool>

Either true to allow merging pull requests with a merge commit, or false to prevent merging pull requests with merge commits.

allow_rebase_merge: Option<bool>

Either true to allow rebase-merging pull requests, or false to prevent rebase-merging.

allow_auto_merge: Option<bool>

Either true to allow auto-merge on pull requests, or false to disallow auto-merge.

delete_branch_on_merge: Option<bool>

Either true to allow automatically deleting head branches when pull requests are merged, or false to prevent automatic deletion.

archived: Option<bool>

true to archive this repository. Note: You cannot unarchive repositories through the API.

allow_forking: Option<bool>

Either true to allow private forks, or false to prevent private forks.

additionalProperties: HashMap<Cow<'a, str>, Value>