pub struct Json<'a> {
    pub name: Cow<'a, str>,
    pub description: Option<Cow<'a, str>>,
    pub maintainers: Option<Cow<'a, [Cow<'a, str>]>>,
    pub repo_names: Option<Cow<'a, [Cow<'a, str>]>>,
    pub privacy: Option<Cow<'a, str>>,
    pub permission: Option<Cow<'a, str>>,
    pub parent_team_id: Option<i64>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

name: Cow<'a, str>

The name of the team.

description: Option<Cow<'a, str>>

The description of the team.

maintainers: Option<Cow<'a, [Cow<'a, str>]>>

List GitHub IDs for organization members who will become team maintainers.

repo_names: Option<Cow<'a, [Cow<'a, str>]>>

The full name (e.g., “organization-name/repository-name”) of repositories to add the team to.

privacy: Option<Cow<'a, str>>

The level of privacy this team should have. The options are:
For a non-nested team:
* secret - only visible to organization owners and members of this team.
* closed - visible to all members of this organization.
Default: secret
For a parent or child team:
* closed - visible to all members of this organization.
Default for child team: closed

permission: Option<Cow<'a, str>>

Deprecated. The permission that new repositories will be added to the team with when none is specified. Can be one of:
* pull - team members can pull, but not push to or administer newly-added repositories.
* push - team members can pull and push, but not administer newly-added repositories.
* admin - team members can pull, push and administer newly-added repositories.

parent_team_id: Option<i64>

The ID of a team to set as the parent team.

additionalProperties: HashMap<Cow<'a, str>, Value>