Module jinxapi_github::v1_1_4::request::teams_get_legacy
source · [−]Expand description
Get a team (Legacy)
Deprecation Notice: This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the Get a team by name endpoint.