Module jinxapi_github::v1_1_4::request::teams_list
source · [−]Expand description
List teams
Lists all teams in an organization that are visible to the authenticated user.
List teams
Lists all teams in an organization that are visible to the authenticated user.