Update a team

To edit a team, the authenticated user must either be an organization owner or a team maintainer.

Note: You can also specify a team by org_id and team_id using the route PATCH /organizations/{org_id}/team/{team_id}.

API method documentation

Modules

Types for body parameter in super::teams_update_in_org

Structs

Functions