Module jinxapi_github::v1_1_4::request::users_follow
source · [−]Expand description
Follow a user
Note that you’ll need to set Content-Length to zero when calling out to this endpoint. For more information, see “HTTP verbs.”
Following a user requires the user to be logged in and authenticated with basic auth or OAuth with the user:follow scope.