Module users_get_authenticated

Module users_get_authenticated 

Get the authenticated user

If the authenticated user is authenticated through basic authentication or OAuth with the user scope, then the response lists public and private profile information.

If the authenticated user is authenticated through OAuth without the user scope, then the response lists only public profile information.

API method documentation

Functions

http_builder
hyper_request
reqwest_blocking_builder
reqwest_blocking_request
reqwest_builder
reqwest_request