Module jinxapi_github::v1_1_4::request::users_unfollow
source · [−]Expand description
Unfollow a user
Unfollowing a user requires the user to be logged in and authenticated with basic auth or OAuth with the user:follow scope.