ActionsWorkflowAccessToRepository

Struct ActionsWorkflowAccessToRepository 

pub struct ActionsWorkflowAccessToRepository<'a> {
    pub access_level: Cow<'a, str>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

access_level: Cow<'a, str>

Defines the level of access that workflows outside of the repository have to actions and reusable workflows within the repository. none means access is only possible from workflows in this repository. Can be one of none, organization, enterprise.

additionalProperties: HashMap<Cow<'a, str>, Value>