Struct jinxapi_github::v1_1_4::schema::DeploymentBranchPolicy
source · [−]pub struct DeploymentBranchPolicy<'a> {
pub protected_branches: bool,
pub custom_branch_policies: bool,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Expand description
The type of deployment branch policy for this environment. To allow all branches to deploy, set to null.
Fields
protected_branches: boolWhether only branches with branch protection rules can deploy to this environment. If protected_branches is true, custom_branch_policies must be false; if protected_branches is false, custom_branch_policies must be true.
custom_branch_policies: boolWhether only branches that match the specified name patterns can deploy to this environment. If custom_branch_policies is true, protected_branches must be false; if custom_branch_policies is false, protected_branches must be true.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'a> Clone for DeploymentBranchPolicy<'a>
impl<'a> Clone for DeploymentBranchPolicy<'a>
sourcefn clone(&self) -> DeploymentBranchPolicy<'a>
fn clone(&self) -> DeploymentBranchPolicy<'a>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'a> Debug for DeploymentBranchPolicy<'a>
impl<'a> Debug for DeploymentBranchPolicy<'a>
sourceimpl<'a> Default for DeploymentBranchPolicy<'a>
impl<'a> Default for DeploymentBranchPolicy<'a>
sourcefn default() -> DeploymentBranchPolicy<'a>
fn default() -> DeploymentBranchPolicy<'a>
Returns the “default value” for a type. Read more
sourceimpl<'de, 'a> Deserialize<'de> for DeploymentBranchPolicy<'a>
impl<'de, 'a> Deserialize<'de> for DeploymentBranchPolicy<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<'a> PartialEq<DeploymentBranchPolicy<'a>> for DeploymentBranchPolicy<'a>
impl<'a> PartialEq<DeploymentBranchPolicy<'a>> for DeploymentBranchPolicy<'a>
sourcefn eq(&self, other: &DeploymentBranchPolicy<'a>) -> bool
fn eq(&self, other: &DeploymentBranchPolicy<'a>) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &DeploymentBranchPolicy<'a>) -> bool
fn ne(&self, other: &DeploymentBranchPolicy<'a>) -> bool
This method tests for !=.
sourceimpl<'a> Serialize for DeploymentBranchPolicy<'a>
impl<'a> Serialize for DeploymentBranchPolicy<'a>
impl<'a> Eq for DeploymentBranchPolicy<'a>
impl<'a> StructuralEq for DeploymentBranchPolicy<'a>
impl<'a> StructuralPartialEq for DeploymentBranchPolicy<'a>