Struct jinxapi_github::v1_1_4::schema::InteractionLimit
source · [−]pub struct InteractionLimit<'a> {
pub limit: Cow<'a, str>,
pub expiry: Option<Cow<'a, str>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Expand description
Interaction Restrictions
Limit interactions to a specific type of user for a specified duration
Fields
limit: Cow<'a, str>The type of GitHub user that can comment, open issues, or create pull requests while the interaction limit is in effect. Can be one of: existing_users, contributors_only, collaborators_only.
Example
"collaborators_only"expiry: Option<Cow<'a, str>>The duration of the interaction restriction. Can be one of: one_day, three_days, one_week, one_month, six_months. Default: one_day.
Example
"one_month"additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'a> Clone for InteractionLimit<'a>
impl<'a> Clone for InteractionLimit<'a>
sourcefn clone(&self) -> InteractionLimit<'a>
fn clone(&self) -> InteractionLimit<'a>
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from source. Read more
sourceimpl<'a> Debug for InteractionLimit<'a>
impl<'a> Debug for InteractionLimit<'a>
sourceimpl<'a> Default for InteractionLimit<'a>
impl<'a> Default for InteractionLimit<'a>
sourcefn default() -> InteractionLimit<'a>
fn default() -> InteractionLimit<'a>
Returns the “default value” for a type. Read more
sourceimpl<'de, 'a> Deserialize<'de> for InteractionLimit<'a>
impl<'de, 'a> Deserialize<'de> for InteractionLimit<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<'a> PartialEq<InteractionLimit<'a>> for InteractionLimit<'a>
impl<'a> PartialEq<InteractionLimit<'a>> for InteractionLimit<'a>
sourcefn eq(&self, other: &InteractionLimit<'a>) -> bool
fn eq(&self, other: &InteractionLimit<'a>) -> bool
This method tests for self and other values to be equal, and is used
by ==. Read more
sourcefn ne(&self, other: &InteractionLimit<'a>) -> bool
fn ne(&self, other: &InteractionLimit<'a>) -> bool
This method tests for !=.
sourceimpl<'a> Serialize for InteractionLimit<'a>
impl<'a> Serialize for InteractionLimit<'a>
sourceimpl<'a> TryFrom<&'_ InteractionLimit<'a>> for Content<Body>
impl<'a> TryFrom<&'_ InteractionLimit<'a>> for Content<Body>
sourceimpl<'a> TryFrom<&'_ InteractionLimit<'a>> for Content<Body>
impl<'a> TryFrom<&'_ InteractionLimit<'a>> for Content<Body>
sourceimpl<'a> TryFrom<&'_ InteractionLimit<'a>> for Content<Body>
impl<'a> TryFrom<&'_ InteractionLimit<'a>> for Content<Body>
impl<'a> Eq for InteractionLimit<'a>
impl<'a> StructuralEq for InteractionLimit<'a>
impl<'a> StructuralPartialEq for InteractionLimit<'a>