Module jinxapi_github::v1_1_4::request
source · [−]Modules
Add custom labels to a self-hosted runner for an organization
Add custom labels to a self-hosted runner for a repository
Add repository access to a self-hosted runner group in an organization
Add selected repository to an organization secret
Add a self-hosted runner to a group for an organization
Approve a workflow run for a fork pull request
Cancel a workflow run
Create or update an environment secret
Create or update an organization secret
Create or update a repository secret
Create a registration token for an organization
Create a registration token for a repository
Create a remove token for an organization
Create a remove token for a repository
Create a self-hosted runner group for an organization
Create a workflow dispatch event
Delete an artifact
Delete an environment secret
Delete an organization secret
Delete a repository secret
Delete a self-hosted runner from an organization
Delete a self-hosted runner from a repository
Delete a self-hosted runner group from an organization
Delete a workflow run
Delete workflow run logs
Disable a selected repository for GitHub Actions in an organization
Disable a workflow
Download an artifact
Download job logs for a workflow run
Download workflow run attempt logs
Download workflow run logs
Enable a selected repository for GitHub Actions in an organization
Enable a workflow
Get allowed actions for an organization
Get allowed actions for a repository
Get an artifact
Get an environment public key
Get an environment secret
Get GitHub Actions permissions for an organization
Get GitHub Actions permissions for a repository
Get a job for a workflow run
Get an organization public key
Get an organization secret
Get pending deployments for a workflow run
Get a repository public key
Get a repository secret
Get the review history for a workflow run
Get a self-hosted runner for an organization
Get a self-hosted runner for a repository
Get a self-hosted runner group for an organization
Get a workflow
Get a workflow run
Get a workflow run attempt
Get workflow run usage
Get workflow usage
List artifacts for a repository
List environment secrets
List jobs for a workflow run
List jobs for a workflow run attempt
List labels for a self-hosted runner for an organization
List labels for a self-hosted runner for a repository
List organization secrets
List repository access to a self-hosted runner group in an organization
List repository secrets
List repository workflows
List runner applications for an organization
List runner applications for a repository
List selected repositories for an organization secret
List selected repositories enabled for GitHub Actions in an organization
List self-hosted runner groups for an organization
List self-hosted runners for an organization
List self-hosted runners for a repository
List self-hosted runners in a group for an organization
List workflow run artifacts
List workflow runs
List workflow runs for a repository
Re-run a workflow
Remove all custom labels from a self-hosted runner for an organization
Remove all custom labels from a self-hosted runner for a repository
Remove a custom label from a self-hosted runner for an organization
Remove a custom label from a self-hosted runner for a repository
Remove repository access to a self-hosted runner group in an organization
Remove selected repository from an organization secret
Remove a self-hosted runner from a group for an organization
Review pending deployments for a workflow run
Set allowed actions for an organization
Set allowed actions for a repository
Set custom labels for a self-hosted runner for an organization
Set custom labels for a self-hosted runner for a repository
Set GitHub Actions permissions for an organization
Set GitHub Actions permissions for a repository
Set repository access for a self-hosted runner group in an organization
Set selected repositories for an organization secret
Set selected repositories enabled for GitHub Actions in an organization
Set self-hosted runners in a group for an organization
Update a self-hosted runner group for an organization
Check if a repository is starred by the authenticated user
Delete a repository subscription
Delete a thread subscription
Get feeds
Get a repository subscription
Get a thread
Get a thread subscription for the authenticated user
List events for the authenticated user
List notifications for the authenticated user
List organization events for the authenticated user
List public events
List public events for a network of repositories
List public events for a user
List public organization events
List events received by the authenticated user
List public events received by a user
List repository events
List repository notifications for the authenticated user
List repositories starred by the authenticated user
List repositories starred by a user
List repositories watched by a user
List stargazers
List repositories watched by the authenticated user
List watchers
Mark notifications as read
Mark repository notifications as read
Mark a thread as read
Set a repository subscription
Set a thread subscription
Star a repository for the authenticated user
Unstar a repository for the authenticated user
Add a repository to an app installation
Check a token
Create a GitHub App from a manifest
Create an installation access token for an app
Delete an app authorization
Delete an installation for the authenticated app
Delete an app token
Get the authenticated app
Get an app
Get an installation for the authenticated app
Get an organization installation for the authenticated app
Get a repository installation for the authenticated app
Get a subscription plan for an account
Get a subscription plan for an account (stubbed)
Get a user installation for the authenticated app
Get a webhook configuration for an app
Get a delivery for an app webhook
List accounts for a plan
List accounts for a plan (stubbed)
List repositories accessible to the user access token
List installations for the authenticated app
List app installations accessible to the user access token
List plans
List plans (stubbed)
List repositories accessible to the app installation
List subscriptions for the authenticated user
List subscriptions for the authenticated user (stubbed)
List deliveries for an app webhook
Redeliver a delivery for an app webhook
Remove a repository from an app installation
Reset a token
Revoke an installation access token
Create a scoped access token
Suspend an app installation
Unsuspend an app installation
Update a webhook configuration for an app
Get GitHub Actions billing for an enterprise
Get GitHub Actions billing for an organization
Get GitHub Actions billing for a user
Get GitHub Advanced Security active committers for an enterprise
Get GitHub Advanced Security active committers for an organization
Get GitHub Packages billing for an enterprise
Get GitHub Packages billing for an organization
Get GitHub Packages billing for a user
Get shared storage billing for an enterprise
Get shared storage billing for an organization
Get shared storage billing for a user
Create a check run
Create a check suite
Get a check run
Get a check suite
List check run annotations
List check runs for a Git reference
List check runs in a check suite
List check suites for a Git reference
Rerequest a check run
Rerequest a check suite
Update repository preferences for check suites
Update a check run
Delete a code scanning analysis from a repository
Get a code scanning alert
Get a code scanning analysis for a repository
Get information about a SARIF upload
List instances of a code scanning alert
List code scanning alerts for a repository
List code scanning analyses for a repository
Update a code scanning alert
Upload an analysis as SARIF data
Get all codes of conduct
Get a code of conduct
Add a selected repository to a user secret
List machine types for a codespace
Create a codespace for the authenticated user
Create or update a secret for the authenticated user
Create a codespace from a pull request
Create a codespace in a repository
Delete a codespace for the authenticated user
Delete a secret for the authenticated user
Get a codespace for the authenticated user
Get public key for the authenticated user
Get a secret for the authenticated user
List codespaces for the authenticated user
List codespaces in a repository for the authenticated user
List selected repositories for a user secret
List secrets for the authenticated user
Remove a selected repository from a user secret
List available machine types for a repository
Set selected repositories for a user secret
Start a codespace for the authenticated user
Stop a codespace for the authenticated user
Update a codespace for the authenticated user
Add selected repository to an organization secret
Create or update an organization secret
Create or update a repository secret
Delete an organization secret
Delete a repository secret
Get an organization public key
Get an organization secret
Get a repository public key
Get a repository secret
List organization secrets
List repository secrets
List selected repositories for an organization secret
Remove selected repository from an organization secret
Set selected repositories for an organization secret
Get emojis
Add custom labels to a self-hosted runner for an enterprise
Add organization access to a self-hosted runner group in an enterprise
Add a self-hosted runner to a group for an enterprise
Create a registration token for an enterprise
Create a remove token for an enterprise
Create a self-hosted runner group for an enterprise
Delete a SCIM group from an enterprise
Delete a self-hosted runner from an enterprise
Delete a self-hosted runner group from an enterprise
Delete a SCIM user from an enterprise
Disable a selected organization for GitHub Actions in an enterprise
Enable a selected organization for GitHub Actions in an enterprise
Get allowed actions for an enterprise
Get the audit log for an enterprise
Get GitHub Actions permissions for an enterprise
Get SCIM provisioning information for an enterprise group
Get SCIM provisioning information for an enterprise user
Get a self-hosted runner for an enterprise
Get a self-hosted runner group for an enterprise
List labels for a self-hosted runner for an enterprise
List organization access to a self-hosted runner group in an enterprise
List provisioned SCIM groups for an enterprise
List SCIM provisioned identities for an enterprise
List runner applications for an enterprise
List selected organizations enabled for GitHub Actions in an enterprise
List self-hosted runner groups for an enterprise
List self-hosted runners for an enterprise
List self-hosted runners in a group for an enterprise
Provision a SCIM enterprise group and invite users
Provision and invite a SCIM enterprise user
Remove all custom labels from a self-hosted runner for an enterprise
Remove a custom label from a self-hosted runner for an enterprise
Remove organization access to a self-hosted runner group in an enterprise
Remove a self-hosted runner from a group for an enterprise
Set allowed actions for an enterprise
Set custom labels for a self-hosted runner for an enterprise
Set GitHub Actions permissions for an enterprise
Set SCIM information for a provisioned enterprise group
Set SCIM information for a provisioned enterprise user
Set organization access for a self-hosted runner group in an enterprise
Set selected organizations enabled for GitHub Actions in an enterprise
Set self-hosted runners in a group for an enterprise
Update an attribute for a SCIM enterprise group
Update an attribute for a SCIM enterprise user
Update a self-hosted runner group for an enterprise
Check if a gist is starred
Create a gist
Create a gist comment
Delete a gist
Delete a gist comment
Fork a gist
Get a gist
Get a gist comment
Get a gist revision
List gists for the authenticated user
List gist comments
List gist commits
List gists for a user
List gist forks
List public gists
List starred gists
Star a gist
Unstar a gist
Update a gist
Update a gist comment
Create a blob
Create a commit
Create a reference
Create a tag object
Create a tree
Delete a reference
Get a blob
Get a commit
Get a reference
Get a tag
Get a tree
List matching references
Update a reference
Get all gitignore templates
Get a gitignore template
Get interaction restrictions for your public repositories
Get interaction restrictions for an organization
Get interaction restrictions for a repository
Remove interaction restrictions from your public repositories
Remove interaction restrictions for an organization
Remove interaction restrictions for a repository
Set interaction restrictions for your public repositories
Set interaction restrictions for an organization
Set interaction restrictions for a repository
Add assignees to an issue
Add labels to an issue
Check if a user can be assigned
Create an issue
Create an issue comment
Create a label
Create a milestone
Delete an issue comment
Delete a label
Delete a milestone
Get an issue
Get an issue comment
Get an issue event
Get a label
Get a milestone
List issues assigned to the authenticated user
List assignees
List issue comments
List issue comments for a repository
List issue events
List issue events for a repository
List timeline events for an issue
List user account issues assigned to the authenticated user
List organization issues assigned to the authenticated user
List repository issues
List labels for issues in a milestone
List labels for a repository
List labels for an issue
List milestones
Lock an issue
Remove all labels from an issue
Remove assignees from an issue
Remove a label from an issue
Set labels for an issue
Unlock an issue
Update an issue
Update an issue comment
Update a label
Update a milestone
Get a license
Get all commonly used licenses
Get the license for a repository
Render a Markdown document
Render a Markdown document in raw mode
Get GitHub meta information
Get Octocat
Get the Zen of GitHub
GitHub API Root
Cancel an import
Delete a user migration archive
Delete an organization migration archive
Download an organization migration archive
Download a user migration archive
Get commit authors
Get an import status
Get large files
Get a user migration status
Get an organization migration status
List user migrations
List organization migrations
List repositories for a user migration
List repositories in an organization migration
Map a commit author
Update Git LFS preference
Start a user migration
Start an organization migration
Start an import
Unlock a user repository
Unlock an organization repository
Update an import
Create a new authorization
Delete an authorization
Delete a grant
Get a single authorization
Get a single grant
Get-or-create an authorization for a specific app
Get-or-create an authorization for a specific app and fingerprint
List your authorizations
List your grants
Update an existing authorization
Block a user from an organization
Cancel an organization invitation
Check if a user is blocked by an organization
Check organization membership for a user
Check public organization membership for a user
Convert an organization member to outside collaborator
Create an organization invitation
Create an organization webhook
Delete an organization webhook
Get an organization
Get the audit log for an organization
Get an organization membership for the authenticated user
Get organization membership for a user
Get an organization webhook
Get a webhook configuration for an organization
Get a webhook delivery for an organization webhook
List organizations
List app installations for an organization
List users blocked by an organization
List custom repository roles in an organization
List failed organization invitations
List organizations for the authenticated user
List organizations for a user
List organization invitation teams
List organization members
List organization memberships for the authenticated user
List outside collaborators for an organization
List pending organization invitations
List public organization members
List SAML SSO authorizations for an organization
List deliveries for an organization webhook
List organization webhooks
Ping an organization webhook
Redeliver a delivery for an organization webhook
Remove an organization member
Remove organization membership for a user
Remove outside collaborator from an organization
Remove public organization membership for the authenticated user
Remove a SAML SSO authorization for an organization
Set organization membership for a user
Set public organization membership for the authenticated user
Unblock a user from an organization
Update an organization
Update an organization membership for the authenticated user
Update an organization webhook
Update a webhook configuration for an organization
Delete a package for the authenticated user
Delete a package for an organization
Delete a package for a user
Delete a package version for the authenticated user
Delete package version for an organization
Delete package version for a user
Get all package versions for a package owned by the authenticated user
Get all package versions for a package owned by an organization
Get all package versions for a package owned by a user
Get a package for the authenticated user
Get a package for an organization
Get a package for a user
Get a package version for the authenticated user
Get a package version for an organization
Get a package version for a user
List packages for the authenticated user’s namespace
List packages for an organization
List packages for a user
Restore a package for the authenticated user
Restore a package for an organization
Restore a package for a user
Restore a package version for the authenticated user
Restore package version for an organization
Restore package version for a user
Add project collaborator
Create a project card
Create a project column
Create a user project
Create an organization project
Create a repository project
Delete a project
Delete a project card
Delete a project column
Get a project
Get a project card
Get a project column
Get project permission for a user
List project cards
List project collaborators
List project columns
List organization projects
List repository projects
List user projects
Move a project card
Move a project column
Remove user as a collaborator
Update a project
Update an existing project card
Update an existing project column
Check if a pull request has been merged
Create a pull request
Create a reply for a review comment
Create a review for a pull request
Create a review comment for a pull request
Delete a pending review for a pull request
Delete a review comment for a pull request
Dismiss a review for a pull request
Get a pull request
Get a review for a pull request
Get a review comment for a pull request
List pull requests
List comments for a pull request review
List commits on a pull request
List pull requests files
List requested reviewers for a pull request
List review comments on a pull request
List review comments in a repository
List reviews for a pull request
Merge a pull request
Remove requested reviewers from a pull request
Request reviewers for a pull request
Submit a review for a pull request
Update a pull request
Update a pull request branch
Update a review for a pull request
Update a review comment for a pull request
Get rate limit status for the authenticated user
Create reaction for a commit comment
Create reaction for an issue
Create reaction for an issue comment
Create reaction for a pull request review comment
Create reaction for a release
Create reaction for a team discussion comment
Create reaction for a team discussion comment (Legacy)
Create reaction for a team discussion
Create reaction for a team discussion (Legacy)
Delete a commit comment reaction
Delete an issue reaction
Delete an issue comment reaction
Delete a pull request comment reaction
Delete team discussion reaction
Delete team discussion comment reaction
Delete a reaction (Legacy)
List reactions for a commit comment
List reactions for an issue
List reactions for an issue comment
List reactions for a pull request review comment
List reactions for a team discussion comment
List reactions for a team discussion comment (Legacy)
List reactions for a team discussion
List reactions for a team discussion (Legacy)
Accept a repository invitation
Add app access restrictions
Add a repository collaborator
Add status check contexts
Add team access restrictions
Add user access restrictions
Check if a user is a repository collaborator
Check if vulnerability alerts are enabled for a repository
Compare two commits
Create an autolink reference for a repository
Create a commit comment
Create commit signature protection
Create a commit status
Create a deploy key
Create a deployment
Create a deployment status
Create a repository dispatch event
Create a repository for the authenticated user
Create a fork
Create an organization repository
Create or update an environment
Create or update file contents
Create a GitHub Pages site
Create a release
Create a repository using a template
Create a repository webhook
Decline a repository invitation
Delete a repository
Delete access restrictions
Delete admin branch protection
Delete an environment
Delete an autolink reference from a repository
Delete branch protection
Delete a commit comment
Delete commit signature protection
Delete a deploy key
Delete a deployment
Delete a file
Delete a repository invitation
Delete a GitHub Pages site
Delete pull request review protection
Delete a release
Delete a release asset
Delete a repository webhook
Disable automated security fixes
Disable Git LFS for a repository
Disable vulnerability alerts
Download a repository archive (tar)
Download a repository archive (zip)
Enable automated security fixes
Enable Git LFS for a repository
Enable vulnerability alerts
Generate release notes content for a release
Get a repository
Get access restrictions
Get admin branch protection
Get all environments
Get all status check contexts
Get all repository topics
Get apps with access to the protected branch
Get an autolink reference of a repository
Get a branch
Get branch protection
Get repository clones
Get the weekly commit activity
Get repository permissions for a user
Get the combined status for a specific reference
Get a commit
Get the last year of commit activity
Get a commit comment
Get commit signature protection
Get community profile metrics
Get repository content
Get all contributor commit activity
Get a deploy key
Get a deployment
Get a deployment status
Get an environment
Get latest Pages build
Get the latest release
Get a GitHub Pages site
Get GitHub Pages build
Get a DNS health check for GitHub Pages
Get the weekly commit count
Get pull request review protection
Get the hourly commit count for each day
Get a repository README
Get a repository README for a directory
Get a release
Get a release asset
Get a release by tag name
Get status checks protection
Get teams with access to the protected branch
Get top referral paths
Get top referral sources
Get users with access to the protected branch
Get page views
Get a repository webhook
Get a webhook configuration for a repository
Get a delivery for a repository webhook
List all autolinks of a repository
List branches
List branches for HEAD commit
List repository collaborators
List commit comments
List commit comments for a repository
List commit statuses for a reference
List commits
List repository contributors
List deploy keys
List deployment statuses
List deployments
List repositories for the authenticated user
List organization repositories
List repositories for a user
List forks
List repository invitations
List repository invitations for the authenticated user
List repository languages
List GitHub Pages builds
List public repositories
List pull requests associated with a commit
List release assets
List releases
List repository tags
List repository teams
List deliveries for a repository webhook
List repository webhooks
Merge a branch
Sync a fork branch with the upstream repository
Ping a repository webhook
Redeliver a delivery for a repository webhook
Remove app access restrictions
Remove a repository collaborator
Remove status check contexts
Remove status check protection
Remove team access restrictions
Remove user access restrictions
Rename a branch
Replace all repository topics
Request a GitHub Pages build
Set admin branch protection
Set app access restrictions
Set status check contexts
Set team access restrictions
Set user access restrictions
Test the push repository webhook
Transfer a repository
Update a repository
Update branch protection
Update a commit comment
Update information about a GitHub Pages site
Update a repository invitation
Update pull request review protection
Update a release
Update a release asset
Update status check protection
Update a repository webhook
Update a webhook configuration for a repository
Upload a release asset
Delete a SCIM user from an organization
Get SCIM provisioning information for a user
List SCIM provisioned identities
Provision and invite a SCIM user
Update a provisioned organization membership
Update an attribute for a SCIM user
Search code
Search commits
Search issues and pull requests
Search labels
Search repositories
Search topics
Search users
Get a secret scanning alert
List secret scanning alerts for an enterprise
List secret scanning alerts for an organization
List secret scanning alerts for a repository
List locations for a secret scanning alert
Update a secret scanning alert
Add team member (Legacy)
Add or update team membership for a user
Add or update team membership for a user (Legacy)
Add or update team project permissions
Add or update team project permissions (Legacy)
Add or update team repository permissions
Add or update team repository permissions (Legacy)
Check team permissions for a project
Check team permissions for a project (Legacy)
Check team permissions for a repository
Check team permissions for a repository (Legacy)
Create a team
Create a discussion comment
Create a discussion comment (Legacy)
Create a discussion
Create a discussion (Legacy)
Create or update IdP group connections
Create or update IdP group connections (Legacy)
Delete a discussion comment
Delete a discussion comment (Legacy)
Delete a discussion
Delete a discussion (Legacy)
Delete a team
Delete a team (Legacy)
Get an external group
Get a team by name
Get a discussion comment
Get a discussion comment (Legacy)
Get a discussion
Get a discussion (Legacy)
Get a team (Legacy)
Get team member (Legacy)
Get team membership for a user
Get team membership for a user (Legacy)
Update the connection between an external group and a team
List teams
List child teams
List child teams (Legacy)
List discussion comments
List discussion comments (Legacy)
List discussions
List discussions (Legacy)
List external groups in an organization
List teams for the authenticated user
List IdP groups for a team (Legacy)
List IdP groups for an organization
List IdP groups for a team
List a connection between an external group and a team
List team members
List team members (Legacy)
List pending team invitations
List pending team invitations (Legacy)
List team projects
List team projects (Legacy)
List team repositories
List team repositories (Legacy)
Remove team member (Legacy)
Remove team membership for a user
Remove team membership for a user (Legacy)
Remove a project from a team
Remove a project from a team (Legacy)
Remove a repository from a team
Remove a repository from a team (Legacy)
Remove the connection between an external group and a team
Update a discussion comment
Update a discussion comment (Legacy)
Update a discussion
Update a discussion (Legacy)
Update a team
Update a team (Legacy)
Add an email address for the authenticated user
Block a user
Check if a user is blocked by the authenticated user
Check if a user follows another user
Check if a person is followed by the authenticated user
Create a GPG key for the authenticated user
Create a public SSH key for the authenticated user
Delete an email address for the authenticated user
Delete a GPG key for the authenticated user
Delete a public SSH key for the authenticated user
Follow a user
Get the authenticated user
Get a user
Get contextual information for a user
Get a GPG key for the authenticated user
Get a public SSH key for the authenticated user
List users
List users blocked by the authenticated user
List email addresses for the authenticated user
List the people the authenticated user follows
List followers of the authenticated user
List followers of a user
List the people a user follows
List GPG keys for the authenticated user
List GPG keys for a user
List public email addresses for the authenticated user
List public keys for a user
List public SSH keys for the authenticated user
Set primary email visibility for the authenticated user
Unblock a user
Unfollow a user
Update the authenticated user