Module jinxapi_github::v1_1_4::request::actions_approve_workflow_run
source · [−]Expand description
Approve a workflow run for a fork pull request
Approves a workflow run for a pull request from a public fork of a first time contributor. For more information, see “Approving workflow runs from public forks.“
You must authenticate using an access token with the repo scope to use this endpoint. GitHub Apps must have the actions:write permission to use this endpoint.