Module jinxapi_github::v1_1_4::request::actions_delete_org_secret
source · [−]Expand description
Delete an organization secret
Deletes a secret in an organization using the secret name. You must authenticate using an access token with the admin:org scope to use this endpoint. GitHub Apps must have the secrets organization permission to use this endpoint.