Module jinxapi_github::v1_1_4::request::actions_get_artifact
source · [−]Expand description
Get an artifact
Gets a specific artifact for a workflow run. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the repo scope. GitHub Apps must have the actions:read permission to use this endpoint.