Module jinxapi_github::v1_1_4::request::actions_get_workflow
source · [−]Expand description
Get a workflow
Gets a specific workflow. You can replace workflow_id with the workflow file name. For example, you could use main.yaml. Anyone with read access to the repository can use this endpoint. If the repository is private you must use an access token with the repo scope. GitHub Apps must have the actions:read permission to use this endpoint.