Module jinxapi_github::v1_1_4::request::apps_delete_token
source · [−]Expand description
Delete an app token
OAuth application owners can revoke a single token for an OAuth application. You must use Basic Authentication when accessing this endpoint, using the OAuth application’s client_id and client_secret as the username and password.
Modules
Types for body parameter in super::apps_delete_token