pub struct Json<'a> {
    pub access_token: Cow<'a, str>,
    pub target: Option<Cow<'a, str>>,
    pub target_id: Option<i64>,
    pub repositories: Option<Cow<'a, [Cow<'a, str>]>>,
    pub repository_ids: Option<Cow<'a, [i64]>>,
    pub permissions: Option<AppPermissions<'a>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

access_token: Cow<'a, str>

The OAuth access token used to authenticate to the GitHub API.

Example

"e72e16c7e42f292c6912e7710c838347ae178b4a"
target: Option<Cow<'a, str>>

The name of the user or organization to scope the user-to-server access token to. Required unless target_id is specified.

Example

"octocat"
target_id: Option<i64>

The ID of the user or organization to scope the user-to-server access token to. Required unless target is specified.

Example

1
repositories: Option<Cow<'a, [Cow<'a, str>]>>

The list of repository names to scope the user-to-server access token to. repositories may not be specified if repository_ids is specified.

repository_ids: Option<Cow<'a, [i64]>>

The list of repository IDs to scope the user-to-server access token to. repository_ids may not be specified if repositories is specified.

Example

[
  1
]
permissions: Option<AppPermissions<'a>>

App Permissions

additionalProperties: HashMap<Cow<'a, str>, Value>