Types for fields in Json

Modules

Types for fields in Output

Structs

Check runs can accept a variety of data in the output object, including a title and summary and can optionally provide descriptive details about the run. See the output object description.