Struct jinxapi_github::v1_1_4::request::checks_create::body::json::Output
source · [−]pub struct Output<'a> {
pub title: Cow<'a, str>,
pub summary: Cow<'a, str>,
pub text: Option<Cow<'a, str>>,
pub annotations: Option<Cow<'a, [Annotations<'a>]>>,
pub images: Option<Cow<'a, [Images<'a>]>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Expand description
Check runs can accept a variety of data in the output object, including a title and summary and can optionally provide descriptive details about the run. See the output object description.
Fields
title: Cow<'a, str>The title of the check run.
summary: Cow<'a, str>The summary of the check run. This parameter supports Markdown.
text: Option<Cow<'a, str>>The details of the check run. This parameter supports Markdown.
annotations: Option<Cow<'a, [Annotations<'a>]>>Adds information from your analysis to specific lines of code. Annotations are visible on GitHub in the Checks and Files changed tab of the pull request. The Checks API limits the number of annotations to a maximum of 50 per API request. To create more than 50 annotations, you have to make multiple requests to the Update a check run endpoint. Each time you update the check run, annotations are appended to the list of annotations that already exist for the check run. For details about how you can view annotations on GitHub, see “About status checks”. See the annotations object description for details about how to use this parameter.
images: Option<Cow<'a, [Images<'a>]>>Adds images to the output displayed in the GitHub pull request UI. See the images object description for details.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'de, 'a> Deserialize<'de> for Output<'a>
impl<'de, 'a> Deserialize<'de> for Output<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Output<'a>
impl<'a> StructuralEq for Output<'a>
impl<'a> StructuralPartialEq for Output<'a>