pub struct Json<'a> {
    pub name: Cow<'a, str>,
    pub head_sha: Cow<'a, str>,
    pub details_url: Option<Cow<'a, str>>,
    pub external_id: Option<Cow<'a, str>>,
    pub status: Option<Cow<'a, str>>,
    pub started_at: Option<Cow<'a, str>>,
    pub conclusion: Option<Cow<'a, str>>,
    pub completed_at: Option<Cow<'a, str>>,
    pub output: Option<Output<'a>>,
    pub actions: Option<Cow<'a, [Actions<'a>]>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

name: Cow<'a, str>

The name of the check. For example, “code-coverage”.

head_sha: Cow<'a, str>

The SHA of the commit.

details_url: Option<Cow<'a, str>>

The URL of the integrator’s site that has the full details of the check. If the integrator does not provide this, then the homepage of the GitHub app is used.

external_id: Option<Cow<'a, str>>

A reference for the run on the integrator’s system.

status: Option<Cow<'a, str>>

The current status. Can be one of queued, in_progress, or completed.

started_at: Option<Cow<'a, str>>

The time that the check run began. This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.

conclusion: Option<Cow<'a, str>>

Required if you provide completed_at or a status of completed. The final conclusion of the check. Can be one of action_required, cancelled, failure, neutral, success, skipped, stale, or timed_out. When the conclusion is action_required, additional details should be provided on the site specified by details_url.
Note: Providing conclusion will automatically set the status parameter to completed. You cannot change a check run conclusion to stale, only GitHub can set this.

completed_at: Option<Cow<'a, str>>

The time the check completed. This is a timestamp in ISO 8601 format: YYYY-MM-DDTHH:MM:SSZ.

output: Option<Output<'a>>actions: Option<Cow<'a, [Actions<'a>]>>

Displays a button on GitHub that can be clicked to alert your app to do additional tasks. For example, a code linting app can display a button that automatically fixes detected errors. The button created in this object is displayed after the check run completes. When a user clicks the button, GitHub sends the check_run.requested_action webhook to your app. Each action includes a label, identifier and description. A maximum of three actions are accepted. See the actions object description. To learn more about check runs and requested actions, see “Check runs and requested actions.”

additionalProperties: HashMap<Cow<'a, str>, Value>