Module jinxapi_github::v1_1_4::request::checks_list_annotations
source · [−]Expand description
List check run annotations
Lists annotations for a check run using the annotation id. GitHub Apps must have the checks:read permission on a private repository or pull access to a public repository to get annotations for a check run. OAuth Apps and authenticated users must have the repo scope to get annotations for a check run in a private repository.