Module jinxapi_github::v1_1_4::request::checks_update
source · [−]Expand description
Update a check run
Note: The Checks API only looks for pushes in the repository where the check suite or check run were created. Pushes to a branch in a forked repository are not detected and return an empty pull_requests array.
Updates a check run for a specific commit in a repository. Your GitHub App must have the checks:write permission to edit check runs.
Modules
Types for body parameter in super::checks_update