Module jinxapi_github::v1_1_4::request::code_scanning_update_alert
source · [−]Expand description
Update a code scanning alert
Updates the status of a single code scanning alert. You must use an access token with the security_events scope to use this endpoint with private repositories. You can also use tokens with the public_repo scope for public repositories only. GitHub Apps must have the security_events write permission to use this endpoint.
Modules
Types for body parameter in super::code_scanning_update_alert