Module jinxapi_github::v1_1_4::request::codespaces_get_repo_secret
source · [−]Expand description
Get a repository secret
Gets a single repository secret without revealing its encrypted value. You must authenticate using an access token with the repo scope to use this endpoint. GitHub Apps must have the codespaces_secrets repository permission to use this endpoint.