Module jinxapi_github::v1_1_4::request::dependency_graph_diff_range
source · [−]Expand description
Get a diff of the dependencies between commits
Gets the diff of the dependency changes between two commits of a repository, based on the changes to the dependency manifests made in those commits.