Create a gist

Allows you to add a new gist with one or more files.

Note: Don’t name your files “gistfile” with a numerical suffix. This is the format of the automatic naming scheme that Gist uses internally.

API method documentation

Modules

Types for body parameter in super::gists_create

Structs

Functions