Update a gist

Allows you to update or delete a gist file and rename gist files. Files from the previous version of the gist that aren’t explicitly changed during an edit are unchanged.

API method documentation

Modules

Types for body parameter in super::gists_update

Structs

Functions