Struct jinxapi_github::v1_1_4::request::issues_update::body::Json
source · [−]pub struct Json<'a> {
pub title: Option<Option<Value>>,
pub body: Option<Option<Cow<'a, str>>>,
pub assignee: Option<Option<Cow<'a, str>>>,
pub state: Option<Cow<'a, str>>,
pub milestone: Option<Option<Value>>,
pub labels: Option<Cow<'a, [Value]>>,
pub assignees: Option<Cow<'a, [Cow<'a, str>]>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
title: Option<Option<Value>>The title of the issue.
body: Option<Option<Cow<'a, str>>>The contents of the issue.
assignee: Option<Option<Cow<'a, str>>>Login for the user that this issue should be assigned to. This field is deprecated.
state: Option<Cow<'a, str>>State of the issue. Either open or closed.
milestone: Option<Option<Value>>labels: Option<Cow<'a, [Value]>>Labels to associate with this issue. Pass one or more Labels to replace the set of Labels on this Issue. Send an empty array ([]) to clear all Labels from the Issue. NOTE: Only users with push access can set labels for issues. Labels are silently dropped otherwise.
assignees: Option<Cow<'a, [Cow<'a, str>]>>Logins for Users to assign to this issue. Pass one or more user logins to replace the set of assignees on this Issue. Send an empty array ([]) to clear all assignees from the Issue. NOTE: Only users with push access can set assignees for new issues. Assignees are silently dropped otherwise.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'de, 'a> Deserialize<'de> for Json<'a>
impl<'de, 'a> Deserialize<'de> for Json<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Json<'a>
impl<'a> StructuralEq for Json<'a>
impl<'a> StructuralPartialEq for Json<'a>