Module jinxapi_github::v1_1_4::request::migrations_update_import
source · [−]Expand description
Update an import
An import can be updated with credentials or a project choice by passing in the appropriate parameters in this API request. If no parameters are provided, the import will be restarted.
Some servers (e.g. TFS servers) can have several projects at a single URL. In those cases the import progress will
have the status detection_found_multiple and the Import Progress response will include a project_choices array.
You can select the project to import by providing one of the objects in the project_choices array in the update request.
Modules
Types for body parameter in super::migrations_update_import