Update an import

An import can be updated with credentials or a project choice by passing in the appropriate parameters in this API request. If no parameters are provided, the import will be restarted.

API method documentation

Modules

Types for body parameter in super::migrations_update_import

Structs

Functions