Module jinxapi_github::v1_1_4::request::migrations_update_import
source · [−]Expand description
Update an import
An import can be updated with credentials or a project choice by passing in the appropriate parameters in this API request. If no parameters are provided, the import will be restarted.
Modules
Types for body parameter in super::migrations_update_import