Struct jinxapi_github::v1_1_4::request::orgs_update::body::Json
source · [−]pub struct Json<'a> {Show 21 fields
pub billing_email: Option<Cow<'a, str>>,
pub company: Option<Cow<'a, str>>,
pub email: Option<Cow<'a, str>>,
pub twitter_username: Option<Cow<'a, str>>,
pub location: Option<Cow<'a, str>>,
pub name: Option<Cow<'a, str>>,
pub description: Option<Cow<'a, str>>,
pub has_organization_projects: Option<bool>,
pub has_repository_projects: Option<bool>,
pub default_repository_permission: Option<Cow<'a, str>>,
pub members_can_create_repositories: Option<bool>,
pub members_can_create_internal_repositories: Option<bool>,
pub members_can_create_private_repositories: Option<bool>,
pub members_can_create_public_repositories: Option<bool>,
pub members_allowed_repository_creation_type: Option<Cow<'a, str>>,
pub members_can_create_pages: Option<bool>,
pub members_can_create_public_pages: Option<bool>,
pub members_can_create_private_pages: Option<bool>,
pub members_can_fork_private_repositories: Option<bool>,
pub blog: Option<Cow<'a, str>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
billing_email: Option<Cow<'a, str>>Billing email address. This address is not publicized.
company: Option<Cow<'a, str>>The company name.
email: Option<Cow<'a, str>>The publicly visible email address.
twitter_username: Option<Cow<'a, str>>The Twitter username of the company.
location: Option<Cow<'a, str>>The location.
name: Option<Cow<'a, str>>The shorthand name of the company.
description: Option<Cow<'a, str>>The description of the company.
has_organization_projects: Option<bool>Toggles whether an organization can use organization projects.
has_repository_projects: Option<bool>Toggles whether repositories that belong to the organization can use repository projects.
default_repository_permission: Option<Cow<'a, str>>Default permission level members have for organization repositories:
* read - can pull, but not push to or administer this repository.
* write - can pull and push, but not administer this repository.
* admin - can pull, push, and administer this repository.
* none - no permissions granted by default.
members_can_create_repositories: Option<bool>Toggles the ability of non-admin organization members to create repositories. Can be one of:
* true - all organization members can create repositories.
* false - only organization owners can create repositories.
Default: true
Note: A parameter can override this parameter. See members_allowed_repository_creation_type in this table for details. Note: A parameter can override this parameter. See members_allowed_repository_creation_type in this table for details.
members_can_create_internal_repositories: Option<bool>Toggles whether organization members can create internal repositories, which are visible to all enterprise members. You can only allow members to create internal repositories if your organization is associated with an enterprise account using GitHub Enterprise Cloud or GitHub Enterprise Server 2.20+. Can be one of:
* true - all organization members can create internal repositories.
* false - only organization owners can create internal repositories.
Default: true. For more information, see “Restricting repository creation in your organization” in the GitHub Help documentation.
members_can_create_private_repositories: Option<bool>Toggles whether organization members can create private repositories, which are visible to organization members with permission. Can be one of:
* true - all organization members can create private repositories.
* false - only organization owners can create private repositories.
Default: true. For more information, see “Restricting repository creation in your organization” in the GitHub Help documentation.
members_can_create_public_repositories: Option<bool>Toggles whether organization members can create public repositories, which are visible to anyone. Can be one of:
* true - all organization members can create public repositories.
* false - only organization owners can create public repositories.
Default: true. For more information, see “Restricting repository creation in your organization” in the GitHub Help documentation.
members_allowed_repository_creation_type: Option<Cow<'a, str>>Specifies which types of repositories non-admin organization members can create. Can be one of:
* all - all organization members can create public and private repositories.
* private - members can create private repositories. This option is only available to repositories that are part of an organization on GitHub Enterprise Cloud.
* none - only admin members can create repositories.
Note: This parameter is deprecated and will be removed in the future. Its return value ignores internal repositories. Using this parameter overrides values set in members_can_create_repositories. See the parameter deprecation notice in the operation description for details.
members_can_create_pages: Option<bool>Toggles whether organization members can create GitHub Pages sites. Can be one of:
* true - all organization members can create GitHub Pages sites.
* false - no organization members can create GitHub Pages sites. Existing published sites will not be impacted.
members_can_create_public_pages: Option<bool>Toggles whether organization members can create public GitHub Pages sites. Can be one of:
* true - all organization members can create public GitHub Pages sites.
* false - no organization members can create public GitHub Pages sites. Existing published sites will not be impacted.
members_can_create_private_pages: Option<bool>Toggles whether organization members can create private GitHub Pages sites. Can be one of:
* true - all organization members can create private GitHub Pages sites.
* false - no organization members can create private GitHub Pages sites. Existing published sites will not be impacted.
members_can_fork_private_repositories: Option<bool>Toggles whether organization members can fork private organization repositories. Can be one of:
* true - all organization members can fork private repositories within the organization.
* false - no organization members can fork private repositories within the organization.
blog: Option<Cow<'a, str>>Example
"\"http://github.blog\""additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'de, 'a> Deserialize<'de> for Json<'a>
impl<'de, 'a> Deserialize<'de> for Json<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Json<'a>
impl<'a> StructuralEq for Json<'a>
impl<'a> StructuralPartialEq for Json<'a>