Module jinxapi_github::v1_1_4::request::projects_create_for_repo
source · [−]Expand description
Create a repository project
Creates a repository project board. Returns a 404 Not Found status if projects are disabled in the repository. If you do not have sufficient privileges to perform this action, a 401 Unauthorized or 410 Gone status is returned.
Modules
Types for body parameter in super::projects_create_for_repo