Struct jinxapi_github::v1_1_4::request::pulls_create_review::body::json::Comments
source · [−]pub struct Comments<'a> {
pub path: Cow<'a, str>,
pub position: Option<i64>,
pub body: Cow<'a, str>,
pub line: Option<i64>,
pub side: Option<Cow<'a, str>>,
pub start_line: Option<i64>,
pub start_side: Option<Cow<'a, str>>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
path: Cow<'a, str>The relative path to the file that necessitates a review comment.
position: Option<i64>The position in the diff where you want to add a review comment. Note this value is not the same as the line number in the file. For help finding the position value, read the note below.
body: Cow<'a, str>Text of the review comment.
line: Option<i64>Example
28side: Option<Cow<'a, str>>Example
"RIGHT"start_line: Option<i64>Example
26start_side: Option<Cow<'a, str>>Example
"LEFT"additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
sourceimpl<'de, 'a> Deserialize<'de> for Comments<'a>
impl<'de, 'a> Deserialize<'de> for Comments<'a>
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for Comments<'a>
impl<'a> StructuralEq for Comments<'a>
impl<'a> StructuralPartialEq for Comments<'a>