pub struct Json<'a> {
    pub commit_id: Option<Cow<'a, str>>,
    pub body: Option<Cow<'a, str>>,
    pub event: Option<Cow<'a, str>>,
    pub comments: Option<Cow<'a, [Comments<'a>]>>,
    pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}

Fields

commit_id: Option<Cow<'a, str>>

The SHA of the commit that needs a review. Not using the latest commit SHA may render your review comment outdated if a subsequent commit modifies the line you specify as the position. Defaults to the most recent commit in the pull request when you do not specify a value.

body: Option<Cow<'a, str>>

Required when using REQUEST_CHANGES or COMMENT for the event parameter. The body text of the pull request review.

event: Option<Cow<'a, str>>

The review action you want to perform. The review actions include: APPROVE, REQUEST_CHANGES, or COMMENT. By leaving this blank, you set the review action state to PENDING, which means you will need to submit the pull request review when you are ready.

comments: Option<Cow<'a, [Comments<'a>]>>

Use the following table to specify the location, destination, and contents of the draft review comment.

additionalProperties: HashMap<Cow<'a, str>, Value>