Module jinxapi_github::v1_1_4::request::repos_create_fork
source · [−]Expand description
Create a fork
Create a fork for the authenticated user.
Note: Forking a Repository happens asynchronously. You may have to wait a short period of time before you can access the git objects. If this takes longer than 5 minutes, be sure to contact GitHub Support.
Modules
Types for body parameter in super::repos_create_fork