Module jinxapi_github::v1_1_4::request::repos_get_release_asset
source · [−]Expand description
Get a release asset
To download the asset’s binary content, set the Accept header of the request to application/octet-stream. The API will either redirect the client to the location, or stream it directly if possible. API clients should handle both a 200 or 302 response.