Module jinxapi_github::v1_1_4::request::repos_list_languages
source · [−]Expand description
List repository languages
Lists languages for the specified repository. The value shown for each language is the number of bytes of code written in that language.