Module jinxapi_github::v1_1_4::request::repos_transfer
source · [−]Expand description
Transfer a repository
A transfer request will need to be accepted by the new owner when transferring a personal repository to another user. The response will contain the original owner, and the transfer will continue asynchronously. For more details on the requirements to transfer personal and organization-owned repositories, see about repository transfers.
Modules
Types for body parameter in super::repos_transfer