Module jinxapi_github::v1_1_4::request::repos_update_webhook
source · [−]Expand description
Update a repository webhook
Updates a webhook configured in a repository. If you previously had a secret set, you must provide the same secret or set a new secret or the secret will be removed. If you are only updating individual webhook config properties, use “Update a webhook configuration for a repository.”
Modules
Types for body parameter in super::repos_update_webhook