Module jinxapi_github::v1_1_4::request::secret_scanning_update_alert
source · [−]Expand description
Update a secret scanning alert
Updates the status of a secret scanning alert in an eligible repository.
To use this endpoint, you must be an administrator for the repository or for the organization that owns the repository, and you must use a personal access token with the repo scope or security_events scope.
For public repositories, you may instead use the public_repo scope.
GitHub Apps must have the secret_scanning_alerts write permission to use this endpoint.
Modules
Types for body parameter in super::secret_scanning_update_alert