Module jinxapi_github::v1_1_4::request::teams_create
source · [−]Expand description
Create a team
To create a team, the authenticated user must be a member or owner of {org}. By default, organization members can create teams. Organization owners can limit team creation to organization owners. For more information, see “Setting team creation permissions.”
When you create a new team, you automatically become a team maintainer without explicitly adding yourself to the optional array of maintainers. For more information, see “About teams”.
Modules
Types for body parameter in super::teams_create