Module jinxapi_github::v1_1_4::request::teams_get_member_legacy
source · [−]Expand description
Get team member (Legacy)
The “Get team member” endpoint (described below) is deprecated.
We recommend using the Get team membership for a user endpoint instead. It allows you to get both active and pending memberships.
To list members in a team, the team must be visible to the authenticated user.