Update a discussion comment (Legacy)
Deprecation Notice: This endpoint route is deprecated and will be removed from the Teams API. We recommend migrating your existing code to use the new Update a discussion comment endpoint.
Edits the body text of a discussion comment. OAuth access tokens require the write:discussion scope.
Modules
Types for body parameter in super::teams_update_discussion_comment_legacy