Module jinxapi_github::v1_1_4::request::users_get_authenticated
source · [−]Expand description
Get the authenticated user
If the authenticated user is authenticated through basic authentication or OAuth with the user scope, then the response lists public and private profile information.
If the authenticated user is authenticated through OAuth without the user scope, then the response lists only public profile information.