Module jinxapi_github::v1_1_4::request::users_update_authenticated
source · [−]Expand description
Update the authenticated user
Note: If your email is set to private and you send an email parameter as part of this request to update your profile, your privacy settings are still enforced: the email address will not be displayed on your public profile or via the API.
Modules
Types for body parameter in super::users_update_authenticated