pub struct ActionsWorkflowAccessToRepository<'a> {
pub access_level: Cow<'a, str>,
pub additionalProperties: HashMap<Cow<'a, str>, Value>,
}Fields
access_level: Cow<'a, str>Defines the level of access that workflows outside of the repository have to actions and reusable workflows within the
repository. none means access is only possible from workflows in this repository. Can be one of none, organization, enterprise.
additionalProperties: HashMap<Cow<'a, str>, Value>Trait Implementations
Sourceimpl<'a> Clone for ActionsWorkflowAccessToRepository<'a>
impl<'a> Clone for ActionsWorkflowAccessToRepository<'a>
Sourcefn clone(&self) -> ActionsWorkflowAccessToRepository<'a>
fn clone(&self) -> ActionsWorkflowAccessToRepository<'a>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a> Debug for ActionsWorkflowAccessToRepository<'a>
impl<'a> Debug for ActionsWorkflowAccessToRepository<'a>
Sourceimpl<'a> Default for ActionsWorkflowAccessToRepository<'a>
impl<'a> Default for ActionsWorkflowAccessToRepository<'a>
Sourcefn default() -> ActionsWorkflowAccessToRepository<'a>
fn default() -> ActionsWorkflowAccessToRepository<'a>
Returns the “default value” for a type. Read more
Sourceimpl<'de, 'a> Deserialize<'de> for ActionsWorkflowAccessToRepository<'a>
impl<'de, 'a> Deserialize<'de> for ActionsWorkflowAccessToRepository<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<'a> Eq for ActionsWorkflowAccessToRepository<'a>
Sourceimpl<'a> PartialEq for ActionsWorkflowAccessToRepository<'a>
impl<'a> PartialEq for ActionsWorkflowAccessToRepository<'a>
Sourceimpl<'a> Serialize for ActionsWorkflowAccessToRepository<'a>
impl<'a> Serialize for ActionsWorkflowAccessToRepository<'a>
impl<'a> StructuralPartialEq for ActionsWorkflowAccessToRepository<'a>
Sourceimpl<'a> TryFrom<&ActionsWorkflowAccessToRepository<'a>> for Content<Body>
Available on crate feature hyper only.
impl<'a> TryFrom<&ActionsWorkflowAccessToRepository<'a>> for Content<Body>
Available on crate feature
hyper only.Sourceimpl<'a> TryFrom<&ActionsWorkflowAccessToRepository<'a>> for Content<Body>
Available on crate feature reqwest only.
impl<'a> TryFrom<&ActionsWorkflowAccessToRepository<'a>> for Content<Body>
Available on crate feature
reqwest only.Auto Trait Implementations
impl<'a> Freeze for ActionsWorkflowAccessToRepository<'a>
impl<'a> RefUnwindSafe for ActionsWorkflowAccessToRepository<'a>
impl<'a> Send for ActionsWorkflowAccessToRepository<'a>
impl<'a> Sync for ActionsWorkflowAccessToRepository<'a>
impl<'a> Unpin for ActionsWorkflowAccessToRepository<'a>
impl<'a> UnsafeUnpin for ActionsWorkflowAccessToRepository<'a>
impl<'a> UnwindSafe for ActionsWorkflowAccessToRepository<'a>